# Changelog

## v2021.2.5

([full changelog](https://github.com/NCAR/jupyter-forward/compare/54b2fee0316cd9edf6d3957805b77f515b3fe5b5...4e9951b1f38b81dd5c12fc8db15205fc082f1b58))

- Add development setup [#61](https://github.com/NCAR/jupyter-forward/pull/61) ([@andersy005](https://github.com/andersy005))
- Update PyPI GH action [#60](https://github.com/NCAR/jupyter-forward/pull/60) ([@andersy005](https://github.com/andersy005))
- Add Jupyter executable sanity checks [#59](https://github.com/NCAR/jupyter-forward/pull/59) ([@andersy005](https://github.com/andersy005))
- Pretty print logs with rich [#58](https://github.com/NCAR/jupyter-forward/pull/58) ([@andersy005](https://github.com/andersy005))
- Bump styfle/cancel-workflow-action from 0.6.0 to 0.7.0 [#57](https://github.com/NCAR/jupyter-forward/pull/57) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2020-12-04&to=2021-02-06&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2020-12-04..2021-02-06&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Adependabot+updated%3A2020-12-04..2021-02-06&type=Issues)

## v2020.12.3

- 🔧 Update setuptools-scm settings and Update pypi GHA [#52](https://github.com/NCAR/jupyter-forward/pull/52) ([@andersy005](https://github.com/andersy005))
- ✨ Update authentication scheme [#51](https://github.com/NCAR/jupyter-forward/pull/51) ([@mnlevy1981](https://github.com/mnlevy1981))
- 💚 Fix CI [#50](https://github.com/NCAR/jupyter-forward/pull/50) ([@andersy005](https://github.com/andersy005))
- 🐛 Raise SystemExit when port-forwarding is enabled and local port is not available [#48](https://github.com/NCAR/jupyter-forward/pull/48) ([@andersy005](https://github.com/andersy005))
- Add conda installation info [#47](https://github.com/NCAR/jupyter-forward/pull/47) ([@andersy005](https://github.com/andersy005))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2020-10-28&to=2020-12-03&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2020-10-28..2020-12-03&type=Issues) | [@mnlevy1981](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Amnlevy1981+updated%3A2020-10-28..2020-12-03&type=Issues)

## v2020.10.27

- ⚡ Use try block to exit gracefully. PR [#45](https://github.com/NCAR/jupyter-forward/pull/45) by [@andersy005](https://github.com/andersy005)

- ⚡ Make `log_dir` usage consistent throughout the `RemoteRunner`. PR [#44](https://github.com/NCAR/jupyter-forward/pull/44) by [@andersy005](https://github.com/andersy005)

- ✨ Add `--shell` option. PR [#43](https://github.com/NCAR/jupyter-forward/pull/43) by [@andersy005](https://github.com/andersy005)

- 📚 Update doc references in regards to `--launch-command` option. PR [#42](https://github.com/NCAR/jupyter-forward/pull/42) by [@andersy005](https://github.com/andersy005)

- 📝 Update usage/installation docs. PR [#41](https://github.com/NCAR/jupyter-forward/pull/41) by [@andersy005](https://github.com/andersy005)

- ✨ Add `--version` flag. PR [#39](https://github.com/NCAR/jupyter-forward/pull/39) by [@andersy005](https://github.com/andersy005)

- 📚 Enable documentation on Readthedocs. PR [#37](https://github.com/NCAR/jupyter-forward/pull/37) by [@andersy005](https://github.com/andersy005).

## v2020.10.22.1

- Use setuptools-scm for versioning. PR [#36](https://github.com/NCAR/jupyter-forward/pull/36) by [@andersy005](https://github.com/andersy005).

- Fix changelog formatting. PR [#35](https://github.com/NCAR/jupyter-forward/pull/35) by [@andersy005](https://github.com/andersy005).

- Update PyPI release action. PR [#34](https://github.com/NCAR/jupyter-forward/pull/34) by [@andersy005](https://github.com/andersy005).

## v2020.10.22 and v2020.10.21

- Update README. PR [#33](https://github.com/NCAR/jupyter-forward/pull/33) by [@andersy005](https://github.com/andersy005).

- Fix Header in `latest changes` GH action. PR [#32](https://github.com/NCAR/jupyter-forward/pull/32) by [@andersy005](https://github.com/andersy005).

- Create release via GitHub action. PR [#31](https://github.com/NCAR/jupyter-forward/pull/31) by [@andersy005](https://github.com/andersy005).

- ✨ Add `--launch-command` option. PR [#28](https://github.com/NCAR/jupyter-forward/pull/28) by [@andersy005](https://github.com/andersy005)

- ✨ Use fabric for port-forwarding. PR [#15](https://github.com/NCAR/jupyter-forward/pull/15) by [@andersy005](https://github.com/andersy005) & [@mnlevy1981](https://github.com/mnlevy1981)

- 🐛 Fix auth issue when authenticating with DUO app. PR [#13](https://github.com/NCAR/jupyter-forward/pull139) by [@andersy005](https://github.com/andersy005)

- 📚 Add motivation for jupyter-forward. PR [#12](https://github.com/NCAR/jupyter-forward/pull/12) by [@jukent](https://github.com/jukent)

- ✨ Interrupt a running jupyter server with `Ctrl+C`. PR [#9](https://github.com/NCAR/jupyter-forward/pull/9) by [@andersy005](https://github.com/andersy005)

- 🐛 Fix SSH port-forwarding. PR [#8](https://github.com/NCAR/jupyter-forward/pull/8) by [@andersy005](https://github.com/andersy005)

- ✨ Launch Jupyter Lab with `asynchronous=True`. PR [#4](https://github.com/NCAR/jupyter-forward/pull/4) by [@andersy005](https://github.com/andersy005) & [@mnlevy1981](https://github.com/mnlevy1981)
